==> haskell-xcffib-0.5.1-41-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-21DZAVJxjGRGmyQO6t3aBU
key: xcffib-0.5.1-21DZAVJxjGRGmyQO6t3aBU
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: 2f435cbe3dd4c38dbba67bfa3cc29754
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-21DZAVJxjGRGmyQO6t3aBU
depends:
    base-4.10.0.0 xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z
    language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX filepath-1.4.1.2
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j bytestring-0.10.8.2
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z=ca26f7e7c32a2e6aa34f45c0936c1e8b
             language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX=c6b15acccedbb315ccc03e614fcc3fe0
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=920d793dfdc12d2f05a040a5aead8798
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.5.1-42-i686.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.5.1
id: xcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
key: xcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
license: OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
author: Tycho Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
abi: 549cd34a8f046d41da262192f80a5655
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/xcffib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/xcffib-0.5.1
hs-libraries: HSxcffib-0.5.1-JS1N0PaVvrvKWS58qBRq4H
depends:
    base-4.10.0.0 xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z
    language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX filepath-1.4.1.2
    filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4
    split-0.2.3.2-89BHvn20PlL73pGr1SBIHj containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm bytestring-0.10.8.2
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             xcb-types-0.8.0-EpOJ2VRKLyF9G8YzHLov0Z=ca26f7e7c32a2e6aa34f45c0936c1e8b
             language-python-0.5.4-C0nHOJ1TAMtBM9UDEQKYiX=c6b15acccedbb315ccc03e614fcc3fe0
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             filemanip-0.3.6.3-HRazNawHUwUFMqg3mdq5t4=920d793dfdc12d2f05a040a5aead8798
             split-0.2.3.2-89BHvn20PlL73pGr1SBIHj=c51f43c3e91d41531ae5282d108271a0
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
